@@ -77,17 +77,6 @@ TEST_FIXTURE(EnchantBrokerRequestDictionary_TestFixture,
     CHECK(requestDictionaryCalled);
 }
 
-TEST_FIXTURE(EnchantBrokerRequestDictionary_TestFixture, 
-             EnchantBrokerRequestDictionary_CalledTwice_CallsProviderOnceReturnsSame)
-{
-    _dict = enchant_broker_request_dict(_broker, "en_GB");
-    requestDictionaryCalled = false;
-    EnchantDict* dict = enchant_broker_request_dict(_broker, "en_GB");
-    CHECK(!requestDictionaryCalled);
-
-    CHECK_EQUAL(_dict, dict);
-}
-
 TEST_FIXTURE(EnchantBrokerRequestDictionary_TestFixture, 
              EnchantBrokerRequestDictionary_ProviderDoesNotHave_CallsProvider)
 {
@@ -207,14 +196,6 @@ TEST_FIXTURE(EnchantBrokerRequestDictionary_TestFixture,
 
 }
 
-TEST_FIXTURE(EnchantBrokerRequestDictionary_TestFixture, 
-             EnchantBrokerRequestDictionary_InvalidTag_NULL_ErrorSet)
-{
-    _dict = enchant_broker_request_dict(_broker, "en~US");
-    CHECK_EQUAL((void*)NULL, _dict);
-    CHECK(NULL != enchant_broker_get_error(_broker));
-}
-
 TEST_FIXTURE(EnchantBrokerTestFixture,
              EnchantBrokerRequestDictionary_ProviderLacksListDictionaries_CallbackNeverCalled)
 {
