@@ -85,17 +85,6 @@ TEST_FIXTURE(EnchantBrokerRequestDictionaryWithPwl_TestFixture,
     CHECK(requestDictionaryCalled);
 }
 
-TEST_FIXTURE(EnchantBrokerRequestDictionaryWithPwl_TestFixture,
-             EnchantBrokerRequestDictionaryWithPwl_CalledTwice_CallsProviderOnceReturnsSame)
-{
-    _dict = enchant_broker_request_dict_with_pwl(_broker, "en_GB", _pwlFileName.c_str());
-    requestDictionaryCalled = false;
-    EnchantDict* dict = enchant_broker_request_dict_with_pwl(_broker, "en_GB", _pwlFileName.c_str());
-    CHECK(!requestDictionaryCalled);
-
-    CHECK_EQUAL(_dict, dict);
-}
-
 TEST_FIXTURE(EnchantBrokerRequestDictionaryWithPwl_TestFixture,
              EnchantBrokerRequestDictionaryWithPwl_ProviderDoesNotHave_CallsProvider)
 {
